@@ -32,6 +32,7 @@
 #include "drop-action.h"
 #include "marshal.h"
 #include "actor.h"
+#include "stylable.h"
 
 /* Define this class in GObject system */
 G_DEFINE_TYPE(XfdashboardDragAction,
@@ -239,7 +240,7 @@ static void _xfdashboard_drag_action_set_source(XfdashboardDragAction *self, Clu
 		/* Unset style */
 		if(XFDASHBOARD_IS_ACTOR(priv->source))
 		{
-			xfdashboard_actor_remove_style_pseudo_class(XFDASHBOARD_ACTOR(priv->source), "current-drag-source");
+			xfdashboard_stylable_remove_pseudo_class(XFDASHBOARD_STYLABLE(priv->source), "current-drag-source");
 		}
 
 		/* Release actor */
@@ -320,15 +321,18 @@ static void _xfdashboard_drag_action_on_drag_handle_changed(XfdashboardDragActio
 		XFDASHBOARD_IS_ACTOR(priv->dragHandle))
 	{
 		/* Unset style */
-		styleClass=g_strdup_printf("drag-source-%s", G_OBJECT_TYPE_NAME(priv->source));
-		xfdashboard_actor_remove_style_class(XFDASHBOARD_ACTOR(priv->dragHandle), styleClass);
-		g_free(styleClass);
+		if(priv->source)
+		{
+			styleClass=g_strdup_printf("drag-source-%s", G_OBJECT_TYPE_NAME(priv->source));
+			xfdashboard_stylable_remove_class(XFDASHBOARD_STYLABLE(priv->dragHandle), styleClass);
+			g_free(styleClass);
+		}
 
 		styleClass=g_strdup_printf("drag-actor-%s", G_OBJECT_TYPE_NAME(priv->actor));
-		xfdashboard_actor_remove_style_class(XFDASHBOARD_ACTOR(priv->dragHandle), styleClass);
+		xfdashboard_stylable_remove_class(XFDASHBOARD_STYLABLE(priv->dragHandle), styleClass);
 		g_free(styleClass);
 
-		xfdashboard_actor_remove_style_pseudo_class(XFDASHBOARD_ACTOR(priv->dragHandle), "drag-handle");
+		xfdashboard_stylable_remove_pseudo_class(XFDASHBOARD_STYLABLE(priv->dragHandle), "drag-handle");
 
 		/* Forget drag handle */
 		priv->dragHandle=NULL;
@@ -340,15 +344,18 @@ static void _xfdashboard_drag_action_on_drag_handle_changed(XfdashboardDragActio
 		XFDASHBOARD_IS_ACTOR(priv->dragHandle))
 	{
 		/* Set style */
-		styleClass=g_strdup_printf("drag-source-%s", G_OBJECT_TYPE_NAME(priv->source));
-		xfdashboard_actor_add_style_class(XFDASHBOARD_ACTOR(priv->dragHandle), styleClass);
-		g_free(styleClass);
+		if(priv->source)
+		{
+			styleClass=g_strdup_printf("drag-source-%s", G_OBJECT_TYPE_NAME(priv->source));
+			xfdashboard_stylable_add_class(XFDASHBOARD_STYLABLE(priv->dragHandle), styleClass);
+			g_free(styleClass);
+		}
 
 		styleClass=g_strdup_printf("drag-actor-%s", G_OBJECT_TYPE_NAME(priv->actor));
-		xfdashboard_actor_add_style_class(XFDASHBOARD_ACTOR(priv->dragHandle), styleClass);
+		xfdashboard_stylable_add_class(XFDASHBOARD_STYLABLE(priv->dragHandle), styleClass);
 		g_free(styleClass);
 
-		xfdashboard_actor_add_style_pseudo_class(XFDASHBOARD_ACTOR(priv->dragHandle), "drag-handle");
+		xfdashboard_stylable_add_pseudo_class(XFDASHBOARD_STYLABLE(priv->dragHandle), "drag-handle");
 	}
 
 }
@@ -434,14 +441,14 @@ static void _xfdashboard_drag_action_drag_begin(ClutterDragAction *inAction,
 	priv->lastMotionActors=NULL;
 
 	/* Set styles */
-	if(XFDASHBOARD_IS_ACTOR(priv->source))
+	if(priv->source && XFDASHBOARD_IS_ACTOR(priv->source))
 	{
-		xfdashboard_actor_add_style_pseudo_class(XFDASHBOARD_ACTOR(priv->source), "drag-source");
+		xfdashboard_stylable_add_pseudo_class(XFDASHBOARD_STYLABLE(priv->source), "drag-source");
 	}
 
 	if(XFDASHBOARD_IS_ACTOR(priv->actor))
 	{
-		xfdashboard_actor_add_style_pseudo_class(XFDASHBOARD_ACTOR(priv->source), "dragged");
+		xfdashboard_stylable_add_pseudo_class(XFDASHBOARD_STYLABLE(priv->actor), "dragged");
 	}
 
 	priv->dragHandle=clutter_drag_action_get_drag_handle(CLUTTER_DRAG_ACTION(self));
@@ -450,15 +457,18 @@ static void _xfdashboard_drag_action_drag_begin(ClutterDragAction *inAction,
 	{
 		gchar							*styleClass;
 
-		styleClass=g_strdup_printf("drag-source-%s", G_OBJECT_TYPE_NAME(priv->source));
-		xfdashboard_actor_add_style_class(XFDASHBOARD_ACTOR(priv->dragHandle), styleClass);
-		g_free(styleClass);
+		if(priv->source)
+		{
+			styleClass=g_strdup_printf("drag-source-%s", G_OBJECT_TYPE_NAME(priv->source));
+			xfdashboard_stylable_add_class(XFDASHBOARD_STYLABLE(priv->dragHandle), styleClass);
+			g_free(styleClass);
+		}
 
 		styleClass=g_strdup_printf("drag-actor-%s", G_OBJECT_TYPE_NAME(priv->actor));
-		xfdashboard_actor_add_style_class(XFDASHBOARD_ACTOR(priv->dragHandle), styleClass);
+		xfdashboard_stylable_add_class(XFDASHBOARD_STYLABLE(priv->dragHandle), styleClass);
 		g_free(styleClass);
 
-		xfdashboard_actor_add_style_pseudo_class(XFDASHBOARD_ACTOR(priv->dragHandle), "drag-handle");
+		xfdashboard_stylable_add_pseudo_class(XFDASHBOARD_STYLABLE(priv->dragHandle), "drag-handle");
 
 		/* Get notified if drag handle changes */
 		priv->dragHandleChangedID=g_signal_connect(self, "notify::drag-handle", G_CALLBACK(_xfdashboard_drag_action_on_drag_handle_changed), NULL);
@@ -715,14 +725,14 @@ static void _xfdashboard_drag_action_drag_end(ClutterDragAction *inAction,
 	g_object_ref(self);
 
 	/* Unset styles */
-	if(XFDASHBOARD_IS_ACTOR(priv->source))
+	if(priv->source && XFDASHBOARD_IS_ACTOR(priv->source))
 	{
-		xfdashboard_actor_remove_style_pseudo_class(XFDASHBOARD_ACTOR(priv->source), "drag-source");
+		xfdashboard_stylable_remove_pseudo_class(XFDASHBOARD_STYLABLE(priv->source), "drag-source");
 	}
 
 	if(XFDASHBOARD_IS_ACTOR(priv->actor))
 	{
-		xfdashboard_actor_remove_style_pseudo_class(XFDASHBOARD_ACTOR(priv->source), "dragged");
+		xfdashboard_stylable_remove_pseudo_class(XFDASHBOARD_STYLABLE(priv->actor), "dragged");
 	}
 
 	if(priv->dragHandle &&
@@ -730,15 +740,18 @@ static void _xfdashboard_drag_action_drag_end(ClutterDragAction *inAction,
 	{
 		gchar							*styleClass;
 
-		styleClass=g_strdup_printf("drag-source-%s", G_OBJECT_TYPE_NAME(priv->source));
-		xfdashboard_actor_remove_style_class(XFDASHBOARD_ACTOR(priv->dragHandle), styleClass);
-		g_free(styleClass);
+		if(priv->source)
+		{
+			styleClass=g_strdup_printf("drag-source-%s", G_OBJECT_TYPE_NAME(priv->source));
+			xfdashboard_stylable_remove_class(XFDASHBOARD_STYLABLE(priv->dragHandle), styleClass);
+			g_free(styleClass);
+		}
 
 		styleClass=g_strdup_printf("drag-actor-%s", G_OBJECT_TYPE_NAME(priv->actor));
-		xfdashboard_actor_remove_style_class(XFDASHBOARD_ACTOR(priv->dragHandle), styleClass);
+		xfdashboard_stylable_remove_class(XFDASHBOARD_STYLABLE(priv->dragHandle), styleClass);
 		g_free(styleClass);
 
-		xfdashboard_actor_remove_style_pseudo_class(XFDASHBOARD_ACTOR(priv->dragHandle), "drag-handle");
+		xfdashboard_stylable_remove_pseudo_class(XFDASHBOARD_STYLABLE(priv->dragHandle), "drag-handle");
 
 		priv->dragHandle=NULL;
 	}
@@ -853,7 +866,6 @@ static void _xfdashboard_drag_action_dispose(GObject *inObject)
 	G_OBJECT_CLASS(xfdashboard_drag_action_parent_class)->dispose(inObject);
 }
 
-
 /* Set/get properties */
 static void _xfdashboard_drag_action_set_property(GObject *inObject,
 													guint inPropID,
@@ -921,7 +933,7 @@ void xfdashboard_drag_action_class_init(XfdashboardDragActionClass *klass)
 							_("Source"),
 							_("The source actor where drag began"),
 							CLUTTER_TYPE_ACTOR,
-							G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY);
+							G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS);
 
 	g_object_class_install_properties(gobjectClass, PROP_LAST, XfdashboardDragActionProperties);
 
