@@ -31,7 +31,7 @@
 #include <gtk/gtk.h>
 
 #include "marshal.h"
-#include "image.h"
+#include "image-content.h"
 #include "utils.h"
 
 /* Define this class in GObject system */
@@ -219,6 +219,7 @@ static void _xfdashboard_view_get_property(GObject *inObject,
  */
 static void xfdashboard_view_class_init(XfdashboardViewClass *klass)
 {
+	XfdashboardActorClass	*actorClass=XFDASHBOARD_ACTOR_CLASS(klass);
 	GObjectClass			*gobjectClass=G_OBJECT_CLASS(klass);
 
 	/* Override functions */
@@ -267,6 +268,9 @@ static void xfdashboard_view_class_init(XfdashboardViewClass *klass)
 
 	g_object_class_install_properties(gobjectClass, PROP_LAST, XfdashboardViewProperties);
 
+	/* Define stylable properties */
+	xfdashboard_actor_install_stylable_property(actorClass, XfdashboardViewProperties[PROP_VIEW_ICON]);
+
 	/* Define signals */
 	XfdashboardViewSignals[SIGNAL_ACTIVATING]=
 		g_signal_new("activating",
@@ -511,7 +515,7 @@ void xfdashboard_view_set_icon(XfdashboardView *self, const gchar *inIcon)
 
 		/* Set new icon */
 		if(priv->viewIconImage) g_object_unref(priv->viewIconImage);
-		priv->viewIconImage=xfdashboard_image_new_for_icon_name(priv->viewIcon, 64.0f);
+		priv->viewIconImage=xfdashboard_image_content_new_for_icon_name(priv->viewIcon, 64.0f);
 
 		/* Notify about property change */
 		g_object_notify_by_pspec(G_OBJECT(self), XfdashboardViewProperties[PROP_VIEW_ICON]);
